yakov pushed a commit to branch master.

http://git.enlightenment.org/tools/erigo.git/commit/?id=1255f010bc7c7136724cccec660fb9dbf9862903

commit 1255f010bc7c7136724cccec660fb9dbf9862903
Author: Yakov Goldberg <yako...@samsung.com>
Date:   Mon Nov 23 16:15:33 2015 +0200

    Forbid dragging of dummy widgets
---
 src/bin/gui/editor.c | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/src/bin/gui/editor.c b/src/bin/gui/editor.c
index a047fd8..0508855 100644
--- a/src/bin/gui/editor.c
+++ b/src/bin/gui/editor.c
@@ -595,8 +595,8 @@ _mouse_down_main(void *data EINA_UNUSED, Eo *obj, const 
Eo_Event_Description *de
    _editor_wdg_selected_set(wdg);
    objtree_item_selected_set(wdg);
 
-   /* Start dragging only if mouse down on not main wdg. */
-   if (wdg != wdg_main)
+   /* Start dragging only if mouse down on not dummy or main wdg. */
+   if ((wdg != wdg_main) && (!eid_is_dummy(wdg_eid_get(wdg))))
      _drag_timer_start = ecore_timer_add(0.1, _drag_widget_start, wdg);
    return EO_CALLBACK_CONTINUE;
 }

-- 


Reply via email to